Resolvers
=========

.. automodule:: magql.convert

.. automodule:: magql.resolver_factory

.. autoclass:: magql.resolver_factory.Resolver
   :members:
   :inherited-members:

.. autoclass:: magql.resolver_factory.CamelResolver
   :members:
   :inherited-members:

.. autoclass:: magql.resolver_factory.TableResolver
   :members:
   :inherited-members:

.. autoclass:: magql.resolver_factory.MutationResolver
   :members:
   :inherited-members:

.. autoclass:: magql.resolver_factory.QueryResolver
   :members:
   :inherited-members:

.. autoclass:: magql.resolver_factory.SingleResolver
   :members:
   :inherited-members:

.. autoclass:: magql.resolver_factory.ManyResolver
   :members:
   :inherited-members:
